| plot.twosamp | R Documentation |
twosamp objects.
Plots one-sample survival curves and confidence intervals, paneled by group. plot.twosamp uses base R, whereas plot.twosamptidy use ggplot.
## S3 method for class 'twosamp'
plot(x, ...)
x |
|
... |
Extra parameters to be passed. Other parameters are usually graphical parameters passed to plot and segment calls within function. |
data(leuk2)
## bpcp2samp creates twosamp object
compare_leuk2<-bpcp2samp(leuk2$time,leuk2$status, leuk2$treatment)
# creates base R plot
plot(compare_leuk2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.