| summary.twosamp | R Documentation |
twosamp object.
Creates a data frame with time intervals, survival estimate for each groups, beta estimates, lower and upper pointwise confidence intervals, and p-values
## S3 method for class 'twosamp'
summary(object, ...)
object |
twosamp object |
... |
extra arguments |
creates a data frame. See description.
data(leuk2)
## bpcp2samp creates twosamp object
compare_leuk2<-bpcp2samp(leuk2$time,leuk2$status, leuk2$treatment)
summary(compare_leuk2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.