| twosamp.object | R Documentation |
The twosamp class is returned by the functions bpcp2samp or delta2samp. The class
represents the comparison of two survival curves at each observed event time.
Unlike the htest class, which compares curves at specified testtimes,
the twosamp class compares curves at all observed event times.
Objects of this class has methods for the functions summary and plot.
L |
left endpoint of interval |
Lin |
logical vector, include left endpoint? |
R |
right endpoint of interval |
Rin |
logical vector, include right endpoint? |
interval |
interval of survival and confidence interval as determined by |
g1 |
name of group 1 as determined by |
est_group1 |
one-sample survival estimate for group 1 in interval/at time point |
lower_group1 |
one-sample lower pointwise confidence limit for group 1 in interval/at time point |
upper_group1 |
one-sample upper pointwise confidence limit for group 1 in interval/at time point |
g2 |
name of group 2 as determined by |
est_group2 |
one-sample survival estimate for group 2 in interval/at time point |
lower_group2 |
one-sample lower pointwise confidence limit for group 2 in interval/at time point |
upper_group2 |
one-sample upper pointwise confidence limit for group 2 in interval/at time point |
beta |
estimate of parameter determined by |
lower |
the lower limit of the confidence interval for the parameter determined by |
upper |
the upper limit of the confidence interval for the parameter determined by |
conf.level |
confidence level |
p.value |
p-value for the test |
null.value |
the specificed null hypothesized value of the parameter determined by |
alternative |
type of alternative with respect to the null.value, either 'two.sided', 'greater' or 'less' |
method |
a character string describing the test |
The following components must be included in a legitimate
twosamp
object.
structure(list(L=L, Lin=Lin, R=R, Rin=Rin,
interval=interval,
g1=g1,est_group1 = est_g1, lower_group1=lower_g1, upper_group1=upper_g1,
g2=g2,est_group2 = est_g2, lower_group2=lower_g2, upper_group2=upper_g2,
beta = beta,
lower = lower,
upper = upper,
conf.level = conf.level,
p.value = p.value,
null.value = nullparm,
alternative = alt,
method = full.method), class = c("twosamp","list"))
plot.twosamp,
summary.twosamp
create.twosamp
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.