Learn R Programming

bpcp (version 1.5.1)

summary.twosamp: Summary method for twosamp object.

Description

Creates a data frame with time intervals, survival estimate for each groups, beta estimates, lower and upper pointwise confidence intervals, and p-values

Usage

# S3 method for twosamp
summary(object, ...)

Value

creates a data frame. See description.

Arguments

object

twosamp object

...

extra arguments

Examples

Run this code
data(leuk2)
## bpcp2samp creates twosamp object
compare_leuk2<-bpcp2samp(leuk2$time,leuk2$status, leuk2$treatment)
summary(compare_leuk2)

Run the code above in your browser using DataLab