powered by
twosamp
Creates a data frame with time intervals, survival estimate for each groups, beta estimates, lower and upper pointwise confidence intervals, and p-values
# S3 method for twosamp summary(object, ...)
creates a data frame. See description.
twosamp object
extra arguments
data(leuk2) ## bpcp2samp creates twosamp object compare_leuk2<-bpcp2samp(leuk2$time,leuk2$status, leuk2$treatment) summary(compare_leuk2)
Run the code above in your browser using DataLab